@@ -22,11 +22,11 @@ import urllib.parse
 
 from parameterized import parameterized
 
-from twisted.test.proto_helpers import MemoryReactor
+from twisted.internet.testing import MemoryReactor
 
 import synapse.rest.admin
 from synapse.api.errors import Codes
-from synapse.handlers.device import DeviceHandler
+from synapse.handlers.device import DeviceWriterHandler
 from synapse.rest.client import devices, login
 from synapse.server import HomeServer
 from synapse.util import Clock
@@ -42,7 +42,7 @@ class DeviceRestTestCase(unittest.HomeserverTestCase):
 
     def prepare(self, reactor: MemoryReactor, clock: Clock, hs: HomeServer) -> None:
         handler = hs.get_device_handler()
-        assert isinstance(handler, DeviceHandler)
+        assert isinstance(handler, DeviceWriterHandler)
         self.handler = handler
 
         self.admin_user = self.register_user("admin", "pass", admin=True)
